// src/divider.tsx
import { createVNode as _createVNode } from "vue";
import { defineComponent, computed } from "vue";
import { chakra, useStyleConfig } from "@chakra-ui/vue-system";
import { filterUndefined } from "@chakra-ui/utils";
import { vueThemingProps } from "@chakra-ui/vue-utils";
var CDivider = defineComponent({
  name: "CDivider",
  props: {
    orientation: {
      type: [String],
      default: "horizontal"
    },
    ...vueThemingProps
  },
  setup(props, {
    slots,
    attrs
  }) {
    const themingProps = computed(() => filterUndefined({
      colorScheme: props.colorScheme,
      variant: props.variant,
      size: props.size,
      styleConfig: props.styleConfig,
      orientation: props.orientation
    }));
    const styles = useStyleConfig("Divider", themingProps);
    const {
      borderLeftWidth,
      borderBottomWidth,
      borderTopWidth,
      borderRightWidth,
      borderWidth,
      borderStyle,
      borderColor,
      ...stylesRest
    } = styles.value;
    const dividerStyle = computed(() => {
      const dividerStyles = {
        vertical: {
          borderLeftWidth: borderLeftWidth || borderRightWidth || borderWidth || "1px",
          height: "100%"
        },
        horizontal: {
          borderBottomWidth: borderBottomWidth || borderTopWidth || borderWidth || "1px",
          width: "100%"
        }
      };
      return dividerStyles[props.orientation];
    });
    return () => _createVNode(chakra.hr, {
      "aria-orientation": props.orientation,
      "__css": {
        ...stylesRest,
        border: 0,
        borderColor,
        borderStyle,
        ...dividerStyle.value
      },
      "__label": "divider"
    }, {
      default: () => {
        var _a;
        return [(_a = slots.default) == null ? void 0 : _a.call(slots)];
      }
    });
  }
});

export {
  CDivider
};
